fnss.netconfig.weights.clear_weights — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »

# fnss.netconfig.weights.clear_weights

`clear_weights`(topology)

  Remove all weights from the topology.

  Parameters: | topology : Topology

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »